import logging
import os

from jnpr.junos import Device
from lxml import etree

from inventory_provider import config

SCHEMA_FILENAME = os.path.realpath(os.path.join(
    os.path.dirname(__file__),
    "data",
    "juniper-netconf.xsd"
))


def _load_netconf(hostname, ssh_params):
    dev = Device(
        host=hostname,
        user=ssh_params['username'],
        ssh_private_key_file=ssh_params['private-key'])
    dev.open()
    print(dev.facts)
    return dev.rpc.get_config()


def _routers():
    return [
        'mx1.ham.de.geant.net',
        'mx1.dub.ie.geant.net',
        'mx1.vie.at.geant.net',
        'mx2.rig.lv.geant.net',
        'mx1.mil2.it.geant.net',
        'mx2.bra.sk.geant.net',
        'mx1.ams.nl.geant.net',
        'mx1.dub2.ie.geant.net',
        'mx2.bru.be.geant.net',
        'mx1.ath2.gr.geant.net',
        'mx2.zag.hr.geant.net',
        'mx1.tal.ee.geant.net',
        'mx1.bud.hu.geant.net',
        'mx1.buc.ro.geant.net',
        'mx1.kau.lt.geant.net',
        'mx1.mad.es.geant.net',
        'mx1.fra.de.geant.net',
        'mx2.tal.ee.geant.net',
        'mx1.poz.pl.geant.net',
        'mx2.lis.pt.geant.net',
        'mx1.lon.uk.geant.net',
        'mx1.lon2.uk.geant.net',
        'mx2.kau.lt.geant.net',
        'mx1.pra.cz.geant.net',
        'mx1.par.fr.geant.net',
        'mx2.lju.si.geant.net',
        'mx1.sof.bg.geant.net',
        'mx1.mar.fr.geant.net',
        'mx2.ath.gr.geant.net',
        'mx1.lis.pt.geant.net',
        'mx1.gen.ch.geant.net',
    ]


if __name__ == "__main__":

    logging.basicConfig(level=logging.INFO)

    TEST_DATA_DIR = os.path.dirname(__file__)
    CONFIG_FILENAME = "config.json"
    SCHEMA_FILENAME = os.path.join(TEST_DATA_DIR, "juniper-netconf.xsd")

    with open("config.json") as f:
        params = config.load(f)
    for r in _routers():
        logging.info("router: " + r)
        netconf = _load_netconf(r, params['ssh'])
        filename = os.path.join(
            TEST_DATA_DIR,
            "%s-netconf.xml" % r)
        with open(filename, 'w') as f:
            f.write(etree.tostring(netconf, encoding='unicode'))
